==> klayout-0.21.19.tar.gz: klayout-0.21.19/src/dbStatic.cc <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#include "dbStatic.h"
#include "tlException.h"

namespace db
{

// -----------------------------------------------------------
//  editable mode

bool ms_editable = false;

void set_editable_mode (bool editable)
{
  ms_editable = editable;
}

void check_editable_mode (const char *f_str)
{
  if (! ms_editable) {
    throw tl::Exception (tl::translate ("Function '%s' is permitted only in editable mode").c_str (), f_str);
  }
}

void check_editable_mode ()
{
  if (! ms_editable) {
    throw tl::Exception (tl::translate ("Operation is permitted only in editable mode"));
  }
}

// -----------------------------------------------------------
//  undo enable 

bool ms_transactions_enabled = true;

void enable_transactions (bool enable)
{
  ms_transactions_enabled = enable;
}

}

==> klayout-0.23.10.tar.gz: klayout-0.23.10/src/dbStatic.cc <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2015 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#include "dbStatic.h"
#include "tlException.h"

#include <cstdio>

namespace db
{

// -----------------------------------------------------------
//  editable mode

KLAYOUT_DLL bool ms_editable = false;

void set_default_editable_mode (bool editable)
{
  ms_editable = editable;
}

void check_editable_mode (const char *f_str)
{
  if (! ms_editable) {
    throw tl::Exception (tl::translate ("Function '%s' is permitted only in editable mode"), f_str);
  }
}

void check_editable_mode ()
{
  if (! ms_editable) {
    throw tl::Exception (tl::translate ("Operation is permitted only in editable mode"));
  }
}

// -----------------------------------------------------------
//  number of points per circle

KLAYOUT_DLL unsigned int ms_num_circle_points = 32;

void set_num_circle_points (unsigned int n)
{
  ms_num_circle_points = n;
}

// -----------------------------------------------------------
//  undo enable 

KLAYOUT_DLL bool ms_transactions_enabled = true;

void enable_transactions (bool enable)
{
  ms_transactions_enabled = enable;
}

}
